/*
 * Copyright 2000-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.portals.jetspeed.valve;

import java.security.Principal;

import javax.security.auth.Subject;

import org.apache.jetspeed.pipeline.PipelineException;

import org.apache.jetspeed.pipeline.valve.ValveContext;
import org.apache.jetspeed.request.RequestContext;
import org.apache.jetspeed.security.impl.AbstractSecurityValve;
import org.apache.portals.graffito.context.CmsRequestContext;
import org.apache.portals.graffito.context.CmsRequestContextManager;
import org.apache.portals.graffito.context.impl.CmsRequestContextImpl;

/**
 * Jetspeed 2 valve used to initialise the Graffito request context with the current Subject
 * 
 * @author <a href="mailto:christophe.lombart@sword-technologies.com">Lombart Christophe </a>
 * @version $Id: Exp $
 */
public class GraffitoContextValve extends AbstractSecurityValve
{

    private CmsRequestContextManager cmsRequestContextManager;
    
    /**
     * Constructor
     * 
     * @param cmsRequestContextManager
     */
    public GraffitoContextValve(CmsRequestContextManager cmsRequestContextManager)
    {       
       this.cmsRequestContextManager = cmsRequestContextManager;    
    }
    
    /**
     * 
     * @see org.apache.jetspeed.pipeline.valve.Valve#invoke(org.apache.jetspeed.request.RequestContext, org.apache.jetspeed.pipeline.valve.ValveContext)
     */
    public void invoke(RequestContext request, ValveContext context) throws PipelineException
    {
        Subject subject = getSubject(request);
        CmsRequestContext cmsRequestContext = new CmsRequestContextImpl();
        cmsRequestContext.setSubject(subject);
        cmsRequestContextManager.setCurrentCmsRequestContext(cmsRequestContext);
        context.invokeNext(request);

    }
    
    
    protected Subject getSubject(RequestContext request)
    {
        try 
        {
            return getSubjectFromSession(request);
        }
        catch(Exception e)
        {
            return null;
        }
    }
    
    protected Principal getUserPrincipal(RequestContext context)
    {
        return getUserPrincipal(context);
    }
}
