
-----------------------------------------------------------------------------
-- SERVER
-----------------------------------------------------------------------------
drop table SERVER if exists;

CREATE TABLE SERVER
(
            SERVER_ID integer,
            SCOPE VARCHAR (254),
            ALIAS VARCHAR (254),
            DESCRIPTION VARCHAR (254),
            TITLE VARCHAR (254),
            PLUGIN_CLASS_NAME VARCHAR (254),
    PRIMARY KEY(SERVER_ID),
    UNIQUE (SCOPE),
    UNIQUE (ALIAS)
);


-----------------------------------------------------------------------------
-- WEBDAV_SERVER
-----------------------------------------------------------------------------
drop table WEBDAV_SERVER if exists;

CREATE TABLE WEBDAV_SERVER
(
            SERVER_ID integer,
            URL VARCHAR (254),
            IS_SECURE_SERVER VARCHAR (1),
            USE_CURRENT_LOGIN VARCHAR (1),
            LOGIN VARCHAR (50),
            PASSWORD VARCHAR (50),
    PRIMARY KEY(SERVER_ID),
    UNIQUE (URL)
);


-----------------------------------------------------------------------------
-- GRAFFITO_DB_SERVER
-----------------------------------------------------------------------------
drop table GRAFFITO_DB_SERVER if exists;

CREATE TABLE GRAFFITO_DB_SERVER
(
            SERVER_ID integer,
            PLATEFORM VARCHAR (254),
            DB_ALIAS VARCHAR (254),
            JDBC_LEVEL VARCHAR (10),
            DRIVER VARCHAR (255),
            PROTOCOL VARCHAR (25),
            SUBPROTOCOL VARCHAR (25),
            LOGIN VARCHAR (50),
            PASSWORD VARCHAR (50),
            DATASOURCE VARCHAR (100),
    PRIMARY KEY(SERVER_ID),
    UNIQUE (DB_ALIAS)
);


-----------------------------------------------------------------------------
-- GRAFFITO_FS_SERVER
-----------------------------------------------------------------------------
drop table GRAFFITO_FS_SERVER if exists;

CREATE TABLE GRAFFITO_FS_SERVER
(
            SERVER_ID integer,
            ROOT VARCHAR (254),
    PRIMARY KEY(SERVER_ID),
    UNIQUE (ROOT)
);


-----------------------------------------------------------------------------
-- CONTENT
-----------------------------------------------------------------------------
drop table CONTENT if exists;

CREATE TABLE CONTENT
(
            CONTENT_ID integer,
            CONTENT LONGVARBINARY,
            ENCODING VARCHAR (30),
    PRIMARY KEY(CONTENT_ID)
);


-----------------------------------------------------------------------------
-- CMS_OBJECT
-----------------------------------------------------------------------------
drop table CMS_OBJECT if exists;

CREATE TABLE CMS_OBJECT
(
            OBJECT_ID integer,
            PARENT_ID integer,
            NAME VARCHAR (254),
            URI VARCHAR (254),
            CREATION_DATE date,
            DELTA date,
            DESCRIPTION VARCHAR (255),
            TITLE VARCHAR (255),
            LINK_TARGET_ID integer,
            VERSION_NUM VARCHAR (10),
            IS_LAST_VERSION integer,
            CONTENT_ID integer,
            CONTENT_SIZE integer,
            LANGUAGE VARCHAR (254),
            OWNER VARCHAR (254),
            CONTENT_TYPE VARCHAR (254),
            CLASS_NAME VARCHAR (254),
    PRIMARY KEY(OBJECT_ID),
    UNIQUE (URI, VERSION_NUM)
);

CREATE  INDEX CMS_OBJECT_IDX1 ON CMS_OBJECT (PARENT_ID);
CREATE  INDEX CMS_OBJECT_IDX2 ON CMS_OBJECT (CONTENT_ID);
-----------------------------------------------------------------------------
-- VERSION_HISTORY
-----------------------------------------------------------------------------
drop table VERSION_HISTORY if exists;

CREATE TABLE VERSION_HISTORY
(
            HISTORY_ID integer,
            OBJECT_ID integer,
            PREVIOUS_ID integer,
    PRIMARY KEY(HISTORY_ID)
);

CREATE  INDEX VERSION_HISTORY_IDX1 ON VERSION_HISTORY (OBJECT_ID);
CREATE  INDEX VERSION_HISTORY_IDX2 ON VERSION_HISTORY (PREVIOUS_ID);
-----------------------------------------------------------------------------
-- SYS_CMS_CLASSES
-----------------------------------------------------------------------------
drop table SYS_CMS_CLASSES if exists;

CREATE TABLE SYS_CMS_CLASSES
(
            CMS_CLASS_ID VARCHAR (100),
            CMS_CLASS VARCHAR (254),
    PRIMARY KEY(CMS_CLASS_ID)
);



    ALTER TABLE WEBDAV_SERVER
        ADD CONSTRAINT WEBDAV_SERVER_FK_1 FOREIGN KEY (SERVER_ID)
            REFERENCES SERVER (SERVER_ID);


    ALTER TABLE GRAFFITO_DB_SERVER
        ADD CONSTRAINT GRAFFITO_DB_SERVER_FK_1 FOREIGN KEY (SERVER_ID)
            REFERENCES SERVER (SERVER_ID);


    ALTER TABLE GRAFFITO_FS_SERVER
        ADD CONSTRAINT GRAFFITO_FS_SERVER_FK_1 FOREIGN KEY (SERVER_ID)
            REFERENCES SERVER (SERVER_ID);




    ALTER TABLE CMS_OBJECT
        ADD CONSTRAINT CMS_OBJECT_FK_1 FOREIGN KEY (PARENT_ID)
            REFERENCES CMS_OBJECT (OBJECT_ID);
    ALTER TABLE CMS_OBJECT
        ADD CONSTRAINT CMS_OBJECT_FK_2 FOREIGN KEY (CONTENT_ID)
            REFERENCES CONTENT (CONTENT_ID);


    ALTER TABLE VERSION_HISTORY
        ADD CONSTRAINT VERSION_HISTORY_FK_1 FOREIGN KEY (OBJECT_ID)
            REFERENCES CMS_OBJECT (OBJECT_ID);
    ALTER TABLE VERSION_HISTORY
        ADD CONSTRAINT VERSION_HISTORY_FK_2 FOREIGN KEY (PREVIOUS_ID)
            REFERENCES VERSION_HISTORY (HISTORY_ID);




