
# -----------------------------------------------------------------------
# SERVER
# -----------------------------------------------------------------------
drop table if exists SERVER;

CREATE TABLE SERVER
(
		            SERVER_ID INTEGER NOT NULL,
		            SCOPE VARCHAR (254) NOT NULL,
		            ALIAS VARCHAR (254) NOT NULL,
		            DESCRIPTION VARCHAR (254) NOT NULL,
		            TITLE VARCHAR (254) NOT NULL,
		            PLUGIN_CLASS_NAME VARCHAR (254) NOT NULL,
    PRIMARY KEY(SERVER_ID),
    UNIQUE (SCOPE),
    UNIQUE (ALIAS)
);

# -----------------------------------------------------------------------
# WEBDAV_SERVER
# -----------------------------------------------------------------------
drop table if exists WEBDAV_SERVER;

CREATE TABLE WEBDAV_SERVER
(
		            SERVER_ID INTEGER NOT NULL,
		            URL VARCHAR (254) NOT NULL,
		            IS_SECURE_SERVER VARCHAR (1) NOT NULL,
		            USE_CURRENT_LOGIN VARCHAR (1) NOT NULL,
		            LOGIN VARCHAR (50),
		            PASSWORD VARCHAR (50),
    PRIMARY KEY(SERVER_ID),
    FOREIGN KEY (SERVER_ID) REFERENCES SERVER (SERVER_ID)
        ON DELETE CASCADE 
  ,
    UNIQUE (URL)
);

# -----------------------------------------------------------------------
# GRAFFITO_DB_SERVER
# -----------------------------------------------------------------------
drop table if exists GRAFFITO_DB_SERVER;

CREATE TABLE GRAFFITO_DB_SERVER
(
		            SERVER_ID INTEGER NOT NULL,
		            PLATEFORM VARCHAR (254) NOT NULL,
		            DB_ALIAS VARCHAR (254) NOT NULL,
		            JDBC_LEVEL VARCHAR (10) NOT NULL,
		            DRIVER VARCHAR (255) NOT NULL,
		            PROTOCOL VARCHAR (25) NOT NULL,
		            SUBPROTOCOL VARCHAR (25) NOT NULL,
		            LOGIN VARCHAR (50),
		            PASSWORD VARCHAR (50),
		            DATASOURCE VARCHAR (100),
    PRIMARY KEY(SERVER_ID),
    FOREIGN KEY (SERVER_ID) REFERENCES SERVER (SERVER_ID)
        ON DELETE CASCADE 
  ,
    UNIQUE (DB_ALIAS)
);

# -----------------------------------------------------------------------
# GRAFFITO_FS_SERVER
# -----------------------------------------------------------------------
drop table if exists GRAFFITO_FS_SERVER;

CREATE TABLE GRAFFITO_FS_SERVER
(
		            SERVER_ID INTEGER NOT NULL,
		            ROOT VARCHAR (254) NOT NULL,
    PRIMARY KEY(SERVER_ID),
    FOREIGN KEY (SERVER_ID) REFERENCES SERVER (SERVER_ID)
        ON DELETE CASCADE 
  ,
    UNIQUE (ROOT)
);

# -----------------------------------------------------------------------
# CONTENT
# -----------------------------------------------------------------------
drop table if exists CONTENT;

CREATE TABLE CONTENT
(
		            CONTENT_ID INTEGER NOT NULL,
		            CONTENT LONGBLOB,
		            ENCODING VARCHAR (30),
    PRIMARY KEY(CONTENT_ID)
);

# -----------------------------------------------------------------------
# CMS_OBJECT
# -----------------------------------------------------------------------
drop table if exists CMS_OBJECT;

CREATE TABLE CMS_OBJECT
(
		            OBJECT_ID INTEGER NOT NULL,
		            PARENT_ID INTEGER,
		            NAME VARCHAR (254) NOT NULL,
		            URI VARCHAR (254) NOT NULL,
		            CREATION_DATE DATETIME NOT NULL,
		            DELTA DATETIME NOT NULL,
		            DESCRIPTION VARCHAR (255),
		            TITLE VARCHAR (255),
		            LINK_TARGET_ID INTEGER,
		            VERSION_NUM VARCHAR (10),
		            IS_LAST_VERSION INTEGER,
		            CONTENT_ID INTEGER,
		            CONTENT_SIZE INTEGER,
		            LANGUAGE VARCHAR (254) NOT NULL,
		            OWNER VARCHAR (254) NOT NULL,
		            CONTENT_TYPE VARCHAR (254),
		            CLASS_NAME VARCHAR (254) NOT NULL,
    PRIMARY KEY(OBJECT_ID),
    FOREIGN KEY (PARENT_ID) REFERENCES CMS_OBJECT (OBJECT_ID)
        ON DELETE CASCADE 
  ,
    FOREIGN KEY (CONTENT_ID) REFERENCES CONTENT (CONTENT_ID)
        ON DELETE CASCADE 
  ,
    UNIQUE (URI, VERSION_NUM),
    INDEX CMS_OBJECT_IDX1 (PARENT_ID),
    INDEX CMS_OBJECT_IDX2 (CONTENT_ID)
);

# -----------------------------------------------------------------------
# VERSION_HISTORY
# -----------------------------------------------------------------------
drop table if exists VERSION_HISTORY;

CREATE TABLE VERSION_HISTORY
(
		            HISTORY_ID INTEGER NOT NULL,
		            OBJECT_ID INTEGER NOT NULL,
		            PREVIOUS_ID INTEGER,
    PRIMARY KEY(HISTORY_ID),
    FOREIGN KEY (OBJECT_ID) REFERENCES CMS_OBJECT (OBJECT_ID)
        ON DELETE CASCADE 
  ,
    FOREIGN KEY (PREVIOUS_ID) REFERENCES VERSION_HISTORY (HISTORY_ID)
        ON DELETE CASCADE 
  ,
    INDEX VERSION_HISTORY_IDX1 (OBJECT_ID),
    INDEX VERSION_HISTORY_IDX2 (PREVIOUS_ID)
);

# -----------------------------------------------------------------------
# SYS_CMS_CLASSES
# -----------------------------------------------------------------------
drop table if exists SYS_CMS_CLASSES;

CREATE TABLE SYS_CMS_CLASSES
(
		            CMS_CLASS_ID VARCHAR (100) NOT NULL,
		            CMS_CLASS VARCHAR (254) NOT NULL,
    PRIMARY KEY(CMS_CLASS_ID)
);
  
  
  
  
  
  
  
  
