
-----------------------------------------------------------------------------
-- SERVER
-----------------------------------------------------------------------------
DROP TABLE SERVER CASCADE CONSTRAINTS;

CREATE TABLE SERVER
(
    SERVER_ID NUMBER NOT NULL,
    SCOPE VARCHAR2 (254) NOT NULL,
    ALIAS VARCHAR2 (254) NOT NULL,
    DESCRIPTION VARCHAR2 (254) NOT NULL,
    TITLE VARCHAR2 (254) NOT NULL,
    PLUGIN_CLASS_NAME VARCHAR2 (254) NOT NULL,
    CONSTRAINT scope UNIQUE (SCOPE),
    CONSTRAINT alias UNIQUE (ALIAS)
);

ALTER TABLE SERVER
    ADD CONSTRAINT SERVER_PK
PRIMARY KEY (SERVER_ID);



-----------------------------------------------------------------------------
-- WEBDAV_SERVER
-----------------------------------------------------------------------------
DROP TABLE WEBDAV_SERVER CASCADE CONSTRAINTS;

CREATE TABLE WEBDAV_SERVER
(
    SERVER_ID NUMBER NOT NULL,
    URL VARCHAR2 (254) NOT NULL,
    IS_SECURE_SERVER VARCHAR2 (1) NOT NULL,
    USE_CURRENT_LOGIN VARCHAR2 (1) NOT NULL,
    LOGIN VARCHAR2 (50),
    PASSWORD VARCHAR2 (50),
    CONSTRAINT url UNIQUE (URL)
);

ALTER TABLE WEBDAV_SERVER
    ADD CONSTRAINT WEBDAV_SERVER_PK
PRIMARY KEY (SERVER_ID);



-----------------------------------------------------------------------------
-- GRAFFITO_DB_SERVER
-----------------------------------------------------------------------------
DROP TABLE GRAFFITO_DB_SERVER CASCADE CONSTRAINTS;

CREATE TABLE GRAFFITO_DB_SERVER
(
    SERVER_ID NUMBER NOT NULL,
    PLATEFORM VARCHAR2 (254) NOT NULL,
    DB_ALIAS VARCHAR2 (254) NOT NULL,
    JDBC_LEVEL VARCHAR2 (10) NOT NULL,
    DRIVER VARCHAR2 (255) NOT NULL,
    PROTOCOL VARCHAR2 (25) NOT NULL,
    SUBPROTOCOL VARCHAR2 (25) NOT NULL,
    LOGIN VARCHAR2 (50),
    PASSWORD VARCHAR2 (50),
    DATASOURCE VARCHAR2 (100),
    CONSTRAINT dbalias UNIQUE (DB_ALIAS)
);

ALTER TABLE GRAFFITO_DB_SERVER
    ADD CONSTRAINT GRAFFITO_DB_SERVER_PK
PRIMARY KEY (SERVER_ID);



-----------------------------------------------------------------------------
-- GRAFFITO_FS_SERVER
-----------------------------------------------------------------------------
DROP TABLE GRAFFITO_FS_SERVER CASCADE CONSTRAINTS;

CREATE TABLE GRAFFITO_FS_SERVER
(
    SERVER_ID NUMBER NOT NULL,
    ROOT VARCHAR2 (254) NOT NULL,
    CONSTRAINT root UNIQUE (ROOT)
);

ALTER TABLE GRAFFITO_FS_SERVER
    ADD CONSTRAINT GRAFFITO_FS_SERVER_PK
PRIMARY KEY (SERVER_ID);



-----------------------------------------------------------------------------
-- CONTENT
-----------------------------------------------------------------------------
DROP TABLE CONTENT CASCADE CONSTRAINTS;

CREATE TABLE CONTENT
(
    CONTENT_ID NUMBER NOT NULL,
    CONTENT BLOB,
    ENCODING VARCHAR2 (30)
);

ALTER TABLE CONTENT
    ADD CONSTRAINT CONTENT_PK
PRIMARY KEY (CONTENT_ID);



-----------------------------------------------------------------------------
-- CMS_OBJECT
-----------------------------------------------------------------------------
DROP TABLE CMS_OBJECT CASCADE CONSTRAINTS;

CREATE TABLE CMS_OBJECT
(
    OBJECT_ID NUMBER NOT NULL,
    PARENT_ID NUMBER,
    NAME VARCHAR2 (254) NOT NULL,
    URI VARCHAR2 (254) NOT NULL,
    CREATION_DATE DATE NOT NULL,
    DELTA DATE NOT NULL,
    DESCRIPTION VARCHAR2 (255),
    TITLE VARCHAR2 (255),
    LINK_TARGET_ID NUMBER,
    VERSION_NUM VARCHAR2 (10),
    IS_LAST_VERSION NUMBER,
    CONTENT_ID NUMBER,
    CONTENT_SIZE NUMBER,
    LANGUAGE VARCHAR2 (254) NOT NULL,
    OWNER VARCHAR2 (254) NOT NULL,
    CONTENT_TYPE VARCHAR2 (254),
    CLASS_NAME VARCHAR2 (254) NOT NULL,
    CONSTRAINT URI_VERSION_NUM UNIQUE (URI, VERSION_NUM)
);

ALTER TABLE CMS_OBJECT
    ADD CONSTRAINT CMS_OBJECT_PK
PRIMARY KEY (OBJECT_ID);

CREATE INDEX CMS_OBJECT_IDX1 ON CMS_OBJECT (PARENT_ID);
CREATE INDEX CMS_OBJECT_IDX2 ON CMS_OBJECT (CONTENT_ID);


-----------------------------------------------------------------------------
-- VERSION_HISTORY
-----------------------------------------------------------------------------
DROP TABLE VERSION_HISTORY CASCADE CONSTRAINTS;

CREATE TABLE VERSION_HISTORY
(
    HISTORY_ID NUMBER NOT NULL,
    OBJECT_ID NUMBER NOT NULL,
    PREVIOUS_ID NUMBER
);

ALTER TABLE VERSION_HISTORY
    ADD CONSTRAINT VERSION_HISTORY_PK
PRIMARY KEY (HISTORY_ID);

CREATE INDEX VERSION_HISTORY_IDX1 ON VERSION_HISTORY (OBJECT_ID);
CREATE INDEX VERSION_HISTORY_IDX2 ON VERSION_HISTORY (PREVIOUS_ID);


-----------------------------------------------------------------------------
-- SYS_CMS_CLASSES
-----------------------------------------------------------------------------
DROP TABLE SYS_CMS_CLASSES CASCADE CONSTRAINTS;

CREATE TABLE SYS_CMS_CLASSES
(
    CMS_CLASS_ID VARCHAR2 (100) NOT NULL,
    CMS_CLASS VARCHAR2 (254) NOT NULL
);

ALTER TABLE SYS_CMS_CLASSES
    ADD CONSTRAINT SYS_CMS_CLASSES_PK
PRIMARY KEY (CMS_CLASS_ID);




ALTER TABLE WEBDAV_SERVER
    ADD CONSTRAINT WEBDAV_SERVER_FK_1 FOREIGN KEY (SERVER_ID)
    REFERENCES SERVER (SERVER_ID)
ON DELETE CASCADE
;



ALTER TABLE GRAFFITO_DB_SERVER
    ADD CONSTRAINT GRAFFITO_DB_SERVER_FK_1 FOREIGN KEY (SERVER_ID)
    REFERENCES SERVER (SERVER_ID)
ON DELETE CASCADE
;



ALTER TABLE GRAFFITO_FS_SERVER
    ADD CONSTRAINT GRAFFITO_FS_SERVER_FK_1 FOREIGN KEY (SERVER_ID)
    REFERENCES SERVER (SERVER_ID)
ON DELETE CASCADE
;





ALTER TABLE CMS_OBJECT
    ADD CONSTRAINT CMS_OBJECT_FK_1 FOREIGN KEY (PARENT_ID)
    REFERENCES CMS_OBJECT (OBJECT_ID)
ON DELETE CASCADE
;

ALTER TABLE CMS_OBJECT
    ADD CONSTRAINT CMS_OBJECT_FK_2 FOREIGN KEY (CONTENT_ID)
    REFERENCES CONTENT (CONTENT_ID)
ON DELETE CASCADE
;



ALTER TABLE VERSION_HISTORY
    ADD CONSTRAINT VERSION_HISTORY_FK_1 FOREIGN KEY (OBJECT_ID)
    REFERENCES CMS_OBJECT (OBJECT_ID)
ON DELETE CASCADE
;

ALTER TABLE VERSION_HISTORY
    ADD CONSTRAINT VERSION_HISTORY_FK_2 FOREIGN KEY (PREVIOUS_ID)
    REFERENCES VERSION_HISTORY (HISTORY_ID)
ON DELETE CASCADE
;





