
-----------------------------------------------------------------------------
-- SERVER
-----------------------------------------------------------------------------
DROP TABLE SERVER CASCADE;



CREATE TABLE SERVER
(
                                    SERVER_ID integer NOT NULL,
                                    SCOPE varchar (254) NOT NULL,
                                    ALIAS varchar (254) NOT NULL,
                                    DESCRIPTION varchar (254) NOT NULL,
                                    TITLE varchar (254) NOT NULL,
                                    PLUGIN_CLASS_NAME varchar (254) NOT NULL,
    PRIMARY KEY (SERVER_ID),
    CONSTRAINT scope UNIQUE (SCOPE),
    CONSTRAINT alias UNIQUE (ALIAS)
);


-----------------------------------------------------------------------------
-- WEBDAV_SERVER
-----------------------------------------------------------------------------
DROP TABLE WEBDAV_SERVER CASCADE;



CREATE TABLE WEBDAV_SERVER
(
                                      -- REFERENCES SERVER (SERVER_ID)
    SERVER_ID integer NOT NULL,
                                    URL varchar (254) NOT NULL,
                                    IS_SECURE_SERVER varchar (1) NOT NULL,
                                    USE_CURRENT_LOGIN varchar (1) NOT NULL,
                                    LOGIN varchar (50),
                                    PASSWORD varchar (50),
    PRIMARY KEY (SERVER_ID),
    CONSTRAINT url UNIQUE (URL)
);


-----------------------------------------------------------------------------
-- GRAFFITO_DB_SERVER
-----------------------------------------------------------------------------
DROP TABLE GRAFFITO_DB_SERVER CASCADE;



CREATE TABLE GRAFFITO_DB_SERVER
(
                                      -- REFERENCES SERVER (SERVER_ID)
    SERVER_ID integer NOT NULL,
                                    PLATEFORM varchar (254) NOT NULL,
                                    DB_ALIAS varchar (254) NOT NULL,
                                    JDBC_LEVEL varchar (10) NOT NULL,
                                    DRIVER varchar (255) NOT NULL,
                                    PROTOCOL varchar (25) NOT NULL,
                                    SUBPROTOCOL varchar (25) NOT NULL,
                                    LOGIN varchar (50),
                                    PASSWORD varchar (50),
                                    DATASOURCE varchar (100),
    PRIMARY KEY (SERVER_ID),
    CONSTRAINT dbalias UNIQUE (DB_ALIAS)
);


-----------------------------------------------------------------------------
-- GRAFFITO_FS_SERVER
-----------------------------------------------------------------------------
DROP TABLE GRAFFITO_FS_SERVER CASCADE;



CREATE TABLE GRAFFITO_FS_SERVER
(
                                      -- REFERENCES SERVER (SERVER_ID)
    SERVER_ID integer NOT NULL,
                                    ROOT varchar (254) NOT NULL,
    PRIMARY KEY (SERVER_ID),
    CONSTRAINT root UNIQUE (ROOT)
);


-----------------------------------------------------------------------------
-- CONTENT
-----------------------------------------------------------------------------
DROP TABLE CONTENT CASCADE;



CREATE TABLE CONTENT
(
                                    CONTENT_ID integer NOT NULL,
                                    CONTENT,
                                    ENCODING varchar (30),
    PRIMARY KEY (CONTENT_ID)
);


-----------------------------------------------------------------------------
-- CMS_OBJECT
-----------------------------------------------------------------------------
DROP TABLE CMS_OBJECT CASCADE;



CREATE TABLE CMS_OBJECT
(
                                    OBJECT_ID integer NOT NULL,
                                      -- REFERENCES CMS_OBJECT (OBJECT_ID)
    PARENT_ID integer,
                                    NAME varchar (254) NOT NULL,
                                    URI varchar (254) NOT NULL,
                                    CREATION_DATE date NOT NULL,
                                    DELTA date NOT NULL,
                                    DESCRIPTION varchar (255),
                                    TITLE varchar (255),
                                    LINK_TARGET_ID integer,
                                    VERSION_NUM varchar (10),
                                    IS_LAST_VERSION integer,
                                      -- REFERENCES CONTENT (CONTENT_ID)
    CONTENT_ID integer,
                                    CONTENT_SIZE integer,
                                    LANGUAGE varchar (254) NOT NULL,
                                    OWNER varchar (254) NOT NULL,
                                    CONTENT_TYPE varchar (254),
                                    CLASS_NAME varchar (254) NOT NULL,
    PRIMARY KEY (OBJECT_ID),
    CONSTRAINT URI_VERSION_NUM UNIQUE (URI, VERSION_NUM)
);
CREATE INDEX CMS_OBJECT_IDX1 ON CMS_OBJECT (PARENT_ID);
CREATE INDEX CMS_OBJECT_IDX2 ON CMS_OBJECT (CONTENT_ID);


-----------------------------------------------------------------------------
-- VERSION_HISTORY
-----------------------------------------------------------------------------
DROP TABLE VERSION_HISTORY CASCADE;



CREATE TABLE VERSION_HISTORY
(
                                    HISTORY_ID integer NOT NULL,
                                      -- REFERENCES CMS_OBJECT (OBJECT_ID)
    OBJECT_ID integer NOT NULL,
                                      -- REFERENCES VERSION_HISTORY (HISTORY_ID)
    PREVIOUS_ID integer,
    PRIMARY KEY (HISTORY_ID)
);
CREATE INDEX VERSION_HISTORY_IDX1 ON VERSION_HISTORY (OBJECT_ID);
CREATE INDEX VERSION_HISTORY_IDX2 ON VERSION_HISTORY (PREVIOUS_ID);


-----------------------------------------------------------------------------
-- SYS_CMS_CLASSES
-----------------------------------------------------------------------------
DROP TABLE SYS_CMS_CLASSES CASCADE;



CREATE TABLE SYS_CMS_CLASSES
(
                                    CMS_CLASS_ID varchar (100) NOT NULL,
                                    CMS_CLASS varchar (254) NOT NULL,
    PRIMARY KEY (CMS_CLASS_ID)
);


----------------------------------------------------------------------
-- SYS_CMS_CLASSES                                                      
----------------------------------------------------------------------


----------------------------------------------------------------------
-- SERVER                                                      
----------------------------------------------------------------------

ALTER TABLE WEBDAV_SERVER
    ADD CONSTRAINT WEBDAV_SERVER_FK_1 FOREIGN KEY (SERVER_ID)
    REFERENCES SERVER (SERVER_ID)
    ON DELETE CASCADE 
;

----------------------------------------------------------------------
-- WEBDAV_SERVER                                                      
----------------------------------------------------------------------

ALTER TABLE GRAFFITO_DB_SERVER
    ADD CONSTRAINT GRAFFITO_DB_SERVER_FK_1 FOREIGN KEY (SERVER_ID)
    REFERENCES SERVER (SERVER_ID)
    ON DELETE CASCADE 
;

----------------------------------------------------------------------
-- GRAFFITO_DB_SERVER                                                      
----------------------------------------------------------------------

ALTER TABLE GRAFFITO_FS_SERVER
    ADD CONSTRAINT GRAFFITO_FS_SERVER_FK_1 FOREIGN KEY (SERVER_ID)
    REFERENCES SERVER (SERVER_ID)
    ON DELETE CASCADE 
;

----------------------------------------------------------------------
-- GRAFFITO_FS_SERVER                                                      
----------------------------------------------------------------------


----------------------------------------------------------------------
-- CONTENT                                                      
----------------------------------------------------------------------

ALTER TABLE CMS_OBJECT
    ADD CONSTRAINT CMS_OBJECT_FK_1 FOREIGN KEY (PARENT_ID)
    REFERENCES CMS_OBJECT (OBJECT_ID)
    ON DELETE CASCADE 
;
ALTER TABLE CMS_OBJECT
    ADD CONSTRAINT CMS_OBJECT_FK_2 FOREIGN KEY (CONTENT_ID)
    REFERENCES CONTENT (CONTENT_ID)
    ON DELETE CASCADE 
;

----------------------------------------------------------------------
-- CMS_OBJECT                                                      
----------------------------------------------------------------------

ALTER TABLE VERSION_HISTORY
    ADD CONSTRAINT VERSION_HISTORY_FK_1 FOREIGN KEY (OBJECT_ID)
    REFERENCES CMS_OBJECT (OBJECT_ID)
    ON DELETE CASCADE 
;
ALTER TABLE VERSION_HISTORY
    ADD CONSTRAINT VERSION_HISTORY_FK_2 FOREIGN KEY (PREVIOUS_ID)
    REFERENCES VERSION_HISTORY (HISTORY_ID)
    ON DELETE CASCADE 
;

----------------------------------------------------------------------
-- VERSION_HISTORY                                                      
----------------------------------------------------------------------

